unquad.strategy.jackknife.Jackknife
===================================

.. currentmodule:: unquad.strategy.jackknife

.. autoclass:: Jackknife

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Jackknife.__init__
      ~Jackknife.fit_calibrate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Jackknife.calibration_ids
   
   